@@ -6,3 +6,6 @@
 #  /_/    \_\___/\__|_|  \___/|_| |_| |_|\__, |
 #                                         __/ |
 #                                        |___/
+
+from .image import zscale, gamma_correction, combine_RGB, AstroImage
+from .wcs import get_wcs_pscale, transform_wcs
\ No newline at end of file
